#!/bin/sh

SEAHORSE_AGENT=/usr/bin/seahorse-agent
if [ -x "$SEAHORSE_AGENT" ]; then
	# As for the version 0.9.9, Seahorse Agent replaces GPG Agent and
	# integrates with SSH Agent (see
	# http://live.gnome.org/Seahorse/SessionIntegration for details). So check
	# that the former is NOT running and make sure the latter IS running.
	if [ -n "$GPG_AGENT_INFO" ]; then
		echo >2 "Warning! GPG Agent is running along with Seahorse Agent."
		echo >2 "Seahorse Agent will be used to cache GPG passphrases,"
		echo >2 "and will effectively disable it."
		echo >2 "Consider switching off GPG Agent (see 'use-agent' line"
		echo >2 "in your gpg.conf)."
	fi
	if [ -z "$SSH_AUTH_SOCK" ]; then
		# Doh, SSH Agent is not running yet.
		# Let's run it, there must be an ssh-agent.sh somewhere around...
		for SSH_AGENT_RUNNER in \
			/etc/X11/profile.d/ssh-agent.sh \
			/etc/profile.d/ssh-agent.sh;
		do
			if [ -x "$SSH_AGENT_RUNNER" ]; then
				# Source it, we need it to set environment variables.
				. "$SSH_AGENT_RUNNER"
				break
			fi
		done
		unset SSH_AGENT_RUNNER
	fi
	# So, we warned about GPG Agent if needed, and tried our best to have
	# SSH Agent running. Finally, start the Seahorse Agent.
    eval `$SEAHORSE_AGENT --variables 2>/dev/null`
fi
unset SEAHORSE_AGENT
